/*\file InterpFromMeshToGrid.c
 *\brief: compute diff between observed and modeled velocity
 */

#include "./InterpFromMeshToGrid.h"

void mexFunction( int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[]){

	/*input datasets: */
	double* index=NULL;
	int     nel;
	double* x=NULL;
	int     nods;
	double* y=NULL;
	double* meshdata=NULL;
	double  cornereast;
	double  cornernorth;
	double  xposting;
	double  yposting;
	int     nlines,ncols;
	double  default_value;

	/* output datasets: */
	double* griddata=NULL;
	double* x_m=NULL;
	double* y_m=NULL;


	/*Boot module: */
	MODULEBOOT();

	/*checks on arguments on the matlab side: */
	CheckNumMatlabArguments(nlhs,NLHS,nrhs,NRHS,__FUNCT__,&InterpFromMeshToGridUsage);

	/*Input datasets: */
	FetchData((void**)&index,&nel,NULL,INDEX,"Matrix","Mat");
	FetchData((void**)&x,&nods,NULL,X,"Matrix","Mat");
	FetchData((void**)&y,NULL,NULL,Y,"Matrix","Mat");
	FetchData((void**)&meshdata,NULL,NULL,MESHDATA,"Matrix","Mat");
	FetchData((void**)&cornereast,NULL,NULL,CORNEREAST,"Scalar",NULL);
	FetchData((void**)&cornernorth,NULL,NULL,CORNERNORTH,"Scalar",NULL);
	FetchData((void**)&xposting,NULL,NULL,XPOSTING,"Scalar",NULL);
	FetchData((void**)&yposting,NULL,NULL,YPOSTING,"Scalar",NULL);
	FetchData((void**)&nlines,NULL,NULL,NLINES,"Integer",NULL);
	FetchData((void**)&ncols,NULL,NULL,NCOLS,"Integer",NULL);
	FetchData((void**)&default_value,NULL,NULL,DEFAULTVALUE,"Scalar",NULL);

	/*Call core of computation: */
	InterpFromMeshToGridx(&x_m,&y_m,&griddata,index,x,y,nods,nel,meshdata,cornereast,cornernorth,xposting,yposting,nlines,ncols,default_value);

	/*Write results: */
	WriteData(XM,x_m,ncols+1,NULL,"Vector","Vec");
	WriteData(YM,y_m,nlines+1,NULL,"Vector","Vec");
	WriteData(GRIDDATA,griddata,nlines,ncols,"Matrix","Mat");

	/*Free ressources: */
	//let matlab do this.
	
	/*end module: */
	MODULEEND();
}

void InterpFromMeshToGridUsage(void)
{
	_printf_("   usage:\n");
	_printf_("   [x_m,y_m,griddata]=InterpFromMeshToGrid(index,x,y,data,cornereast,cornernorth,xposting,yposting,nlines,ncols,default_value)\n");
	_printf_("\n");
	_printf_("   where:\n");
	_printf_("\n");
	_printf_("   index,x,y: delaunay triangulation defining the mesh.\n");
	_printf_("   meshdata: vertex values of data to be interpolated.\n");
	_printf_("   cornereast,cornernorth,posting,nlines,ncols: parameters that define the grid\n");
	_printf_("   default_value: value of points located out of the mesh.\n");
}
